@@ -4,12 +4,15 @@
 # 24 Feb 98: begin
 # 11 Mar 98: final tweaks
 
+# full path to directory containing *.edb files, ppm.xe and gsc.
+$dbdir = '/usr/local/telescope/archive/catalogs';
+
 # generally no need to change anything from here on.
 # ==================================================
 
 # set $trace to 1 to see steps in $tracefile
-$tracefile = 'xephemdbd.trace';
-$trace = 1;
+$tracefile = 'xephemdbd.pl.tr';
+$trace = 0;
 
 # set to lock file location
 $lkfile = 'xephemdbd.pid';
@@ -20,7 +23,7 @@ $infifo = 'xephemdbd.in';
 # set to unique output fifo location
 $outfifo = "xephemdbd.$$";
 
-# set to xephemdbd log file
+# set to xephemdbd stderr log file output
 $logfn = "xephemdbd.log";
 
 # certainly no need to change anything from here on.
@@ -36,15 +39,10 @@ require "cgi-lib.pl";
 # autoflush output
 &afon (STDOUT);
 
-# set up log file
-open (LOG, ">>$logfn") || !print "<p>$logfn $!\n" || goto wrapup;
-&afon (LOG);
-printf LOG "xephemdbd.pl $$ started %s UTC from $ENV{'REMOTE_ADDR'}\n", gmtime()."";
-
 # set up trace file, if enabled
-!$trace || open(TR,">>$tracefile") || !print "<p>$tracefile $!\n" || goto wrapup;
+!$trace || open(TR,">$tracefile") || !print "<p>$tracefile $!\n" || goto wrapup;
 !$trace || &afon (TR);
-!$trace || printf TR "xephemdbd.pl $$ started %s UTC from $ENV{'REMOTE_ADDR'}\n", gmtime()."";
+!$trace || print TR "xephemdbd.pl $$ started\n";
 
 # Read in all the variables set by the form so we can access as $input{'name'}
 &ReadParse(*input);
@@ -58,29 +56,29 @@ print "<H2>XEphemdbd Results</H2>\n";
 
 # check versions match.
 $tmp = $input{'VERSION'};
-!$trace || print TR "  checking version match";
+!$trace || print TR "checking version match";
 if ($tmp != $ver) {
     print "<p>Wrong version: $ver <i>vs.</i> $tmp\n";
     goto wrapup;
 }
 
 # make sure we have the fifo to the xephemdbd
-!$trace || print TR "  checking $infifo\n";
-if (! -p $infifo && system ("mkfifo $infifo")) {
+!$trace || print TR "checking $infifo\n";
+if (! -p $infifo && system ("mknod $infifo p")) {
     print "<p>Can not create fifo $infifo: $!\n";
     goto wrapup;
 }
 
 # start xephemdbd -- it knows to exit if already running.
-!$trace || print TR "  checking for xephemdbd\n";
-if (system ("./start-xephemdbd.pl")) {
+!$trace || print TR "checking for xephemdbd\n";
+if (system ("./xephemdbd -vlic $lkfile $infifo $dbdir >> $logfn 2>&1")) {
     print "<p>Can not start xephemdbd\n";
     goto wrapup;
 }
 
 # start building up the command to xephemdbd in $ecmd in the following format:
 # >file,outputmode,types,year,RA,Dec,FOV,Mag[,lat,long,elev]
-!$trace || print TR "  cracking FORM args\n";
+!$trace || print TR "cracking FORM args\n";
 $ecmd = ">$outfifo";
 
 # gather the basic options 
@@ -96,7 +94,7 @@ $obj = 0;
 $obj +=   1 if $input{'PL'};
 $obj +=  14 if $input{'SS'};
 $obj +=  16 if $input{'BS'};
-$obj += 224 if $input{'DS'};
+$obj += 128 if $input{'DS'};
 $obj += 256 if $input{'PP'};
 $obj += 512 if $input{'GS'};
 $ecmd .= ",$obj";
@@ -186,58 +184,50 @@ if ($ops & 6) {
     $ecmd .= ",$elev";
 }
 
-!$trace || print TR "  command = `$ecmd'\n";
+!$trace || print TR "command = `$ecmd'\n";
 
 # give command to xephemdbd to use outfifo and echo results
-!$trace || print TR "  creating $outfifo\n";
-if (!system ("mkfifo -m 0666 $outfifo")) {
-    !$trace || print TR "  opening $infifo\n";
+!$trace || print TR "creating $outfifo\n";
+if (!system ("mknod $outfifo p")) {
+    !$trace || print TR "opening $infifo\n";
     if (open (EIN, ">>$infifo")) {
 	&afon(EIN);
-	!$trace || print TR "  sending command\n";
+	!$trace || print TR "sending command\n";
 	if (print EIN "$ecmd\n") {
-	    !$trace || print TR "  opening $outfifo\n";
+	    !$trace || print TR "opening $outfifo\n";
 	    if (open (EOUT, "<$outfifo")) {
-		!$trace || print TR "  reading $outfifo\n";
+		!$trace || print TR "reading $outfifo\n";
 		# finally! copy result back to client
 		print "<pre>\n";
 		while (<EOUT>) {
 		    print "$_";
 		}
 		print "</pre>\n";
-		!$trace || print TR "  closing $outfifo\n";
 		close (EOUT);
 	    } else {
-		!$trace || print TR "  opening $outfifo failed\n";
 		print "<p>Opening $outfifo failed: $!\n";
 		goto wrapup;
 	    }
 	} else {
-	    !$trace || print TR "  printing to $infifo failed\n";
 	    print "<p>Print to $infifo failed: $!\n";
 	    goto wrapup;
 	}
 	close (EIN);
     } else {
-	!$trace || print TR "  opening $infifo failed\n";
 	print "<p>Opening $infifo failed: $!\n";
 	goto wrapup;
     }
+    unlink ($outfifo);
 } else {
-    !$trace || print TR "  creating $outfifo failed\n";
     print "<p>Creating $outfifo failed: $!\n";
     goto wrapup;
 }
 
-!$trace || print TR "  finished successfully\n";
+!$trace || print TR "finished successfully\n";
 
 # final boilerplate
 wrapup:
-!$trace || print TR "  wrapup\n";
-
-# remove temp response fifo
-!$trace || print TR "  unlinking $outfifo\n";
-unlink ($outfifo);
+!$trace || print TR "wrapup\n";
 
 print <<ENDOFTEXT;
 <p>Use your browser's \"Go back\" feature to modify the same request.
@@ -267,6 +257,3 @@ sub afon {
     # "bizarre and obscure", Programming Perl, page 211
     select ((select(@_[0]), $| = 1)[0]);
 }
-
-# For RCS Only -- Do Not Edit
-# @(#) $RCSfile: xephemdbd.pl,v $ $Date: 2003/12/05 06:27:38 $ $Revision: 1.5 $ $Name:  $
